@@ -56,6 +56,11 @@ Called by the `copy.deepcopy` standard library function.
         return self.copy()
     #--- End: def
 
+    def __hash__(self):
+        '''
+'''
+        return hash((self.__class__.__name__, self.size, self.ncdim))
+
     def __repr__(self):
         '''
 Called by the `repr` built-in function.
