@@ -1349,7 +1349,10 @@ def _create_bounded_item(nc, ncvar, attributes, f, dimension=False,
     ncbounds = properties.pop('bounds', None)
     if ncbounds is None:
         ncbounds = properties.pop('climatology', None)
-        climatology = True
+        if ncbounds is None:
+            climatology = False
+        else:
+            climatology = True
     else:
         climatology = False
 
