@@ -49,7 +49,7 @@ def write(fields, filename, fmt='NETCDF4', overwrite=True,
           verbose=False, cfa_options=None, mode='w',
           least_significant_digit=None, endian='native', compress=0,
           fletcher32=False, no_shuffle=False, datatype=None,
-          single=False, double=False, reference_datetime=None,
+          single=None, double=None, reference_datetime=None,
           variable_attributes=None, HDF_chunks=None, unlimited=None,
           _debug=False):
     '''Write fields to a CF-netCDF or CFA-netCDF file.
@@ -237,20 +237,30 @@ and auxiliary coordinate roles for different data variables.
     dtype_conversions = {numpy_dtype(bool)  : numpy_dtype('int32'),
                          numpy_dtype(object): numpy_dtype(float)}
     if datatype:
-        if single:
+        if single is not None:
             raise ValueError("Can't set datatype and single")
-        if double:
+        if double is not None:
             raise ValueError("Can't set datatype and double")
         dtype_conversions.update(datatype)
     else:
-        if single and double:
-            raise ValueError("Can't set single and double")
+        if single is not None and double is not None:
+            raise ValueError("Can't set both the single and double parameters")
+
+        if single is not None and not single:
+            double = True
+
+        if double is not None and not double:
+            single = True
+
         if single:
             dtype_conversions[numpy_dtype(float)] = numpy_dtype('float32')
             dtype_conversions[numpy_dtype(int)]   = numpy_dtype('int32')
+
         if double:
             dtype_conversions[numpy_dtype('float32')] = numpy_dtype(float)
             dtype_conversions[numpy_dtype('int32')]   = numpy_dtype(int)
+    #--- End: if
+    
     datatype = dtype_conversions
 
     if not unlimited:
@@ -383,7 +393,7 @@ and auxiliary coordinate roles for different data variables.
     # will prevent the data from being pre-filled with fill values,
     # which may result in some performance improvements.
     # ---------------------------------------------------------------
-    g['netcdf'].set_fill_off()
+#    g['netcdf'].set_fill_off()
 
     # ---------------------------------------------------------------
     # Write global properties to the file first. This is important as
