@@ -12,7 +12,7 @@ def write(fields, filename, fmt='NETCDF4', overwrite=True,
           verbose=False, cfa_options=None, mode='w',
           least_significant_digit=None, endian='native', compress=0,
           fletcher32=False, no_shuffle=False, datatype=None,
-          single=False, double=False, reference_datetime=None,
+          single=None, double=None, reference_datetime=None,
           variable_attributes=None, HDF_chunksizes=None,
           unlimited=None, _debug=False):
     '''Write fields to a netCDF file.
