@@ -48,9 +48,9 @@ class RegridTest(unittest.TestCase):
 
         for chunksize in self.chunk_sizes:
             cf.CHUNKSIZE(chunksize)
-            f1 = cf.read1(self.filename1)
-            f2 = cf.read1(self.filename2)
-            f3 = cf.read1(self.filename3)
+            f1 = cf.read_field(self.filename1)
+            f2 = cf.read_field(self.filename2)
+            f3 = cf.read_field(self.filename3)
             self.assertTrue(f3.equals(f1.regrids(f2, 'conservative'), traceback=True),
                             'destination = global Field, CHUNKSIZE = %s' % chunksize)
             self.assertTrue(f3.equals(f1.regrids(f2, method='conservative'), traceback=True),
@@ -62,8 +62,8 @@ class RegridTest(unittest.TestCase):
             self.assertTrue(f3.equals(f1.regrids(dst, method='conservative',
                                                  dst_cyclic=True), traceback=True),
                             'destination = global dict, CHUNKSIZE = %s' % chunksize)
-            f4 = cf.read1(self.filename4)
-            f5 = cf.read1(self.filename5)
+            f4 = cf.read_field(self.filename4)
+            f5 = cf.read_field(self.filename5)
             self.assertTrue(f4.equals(f1.regrids(f5, 'bilinear'), traceback=True),
                             'destination = regional Field, CHUNKSIZE = %s' % chunksize)
             self.assertTrue(f4.equals(f1.regrids(f5, method='bilinear'), traceback=True),
@@ -71,6 +71,11 @@ class RegridTest(unittest.TestCase):
         #--- End: for
         cf.CHUNKSIZE(self.original_chunksize)
 
+        f6 = cf.read_field(self.filename6)
+        with self.assertRaises(ValueError):
+            f1.regridc(f6, axes='T', method='bilinear')
+        #--- End: with
+        
         cf.ATOL(original_atol)
     #--- End: def
     
@@ -83,14 +88,14 @@ class RegridTest(unittest.TestCase):
 
         for chunksize in self.chunk_sizes:
             cf.CHUNKSIZE(chunksize)
-            f1 = cf.read1(self.filename7)
-            f2 = cf.read1(self.filename8)
-            f3 = cf.read1(self.filename9)
+            f1 = cf.read(self.filename7)[0]
+            f2 = cf.read(self.filename8)[0]
+            f3 = cf.read(self.filename9)[0]
             self.assertTrue(f3.equals(f1.regridc(f2, axes='T', method='bilinear'), traceback=True),
                             'destination = time series, CHUNKSIZE = %s' % chunksize)
-            f4 = cf.read1(self.filename1)
-            f5 = cf.read1(self.filename2)
-            f6 = cf.read1(self.filename10)
+            f4 = cf.read(self.filename1)[0]
+            f5 = cf.read(self.filename2)[0]
+            f6 = cf.read(self.filename10)[0]
             self.assertTrue(f6.equals(f4.regridc(f5, axes=('X', 'Y'), method='conservative'),
                                       traceback=True),
                             'destination = global Field, CHUNKSIZE = %s' % chunksize)
