@@ -13,17 +13,19 @@ class ExamplesTest(unittest.TestCase):
         
         self.assertTrue(
             print_f == 
-            ' field summary\n--------------\n\n')
+            'Field: \n-------\n')
         #--- End: def
 
     def test_example2(self):
-            f = cf.Field(properties={'standard_name': 'air_temperature',
-                                     'long_name': 'temperature of air'})
-            print_f = str(f)
+        f = cf.Field()
+        f.standard_name = 'air_temperature'
+        f.properties({'long_name': 'temperature of air',
+                      'foo'      : 'bar'})
+        print_f = str(f)
         
-            self.assertTrue(
-                print_f ==
-                'air_temperature field summary\n-----------------------------\n\n')
+        self.assertTrue(
+            print_f ==
+            'Field: air_temperature\n----------------------\n')
     #--- End: def
 
     def test_example3(self):
@@ -33,17 +35,20 @@ class ExamplesTest(unittest.TestCase):
                                       properties={'standard_name': 'latitude'})
         dim1 = cf.DimensionCoordinate(data=cf.Data(range(9), 'degrees_east'))
         dim1.standard_name = 'longitude'
-        domain = cf.Domain(dim=[dim0, dim1])
-        f = cf.Field(properties=properties, data=data, domain=domain)
+
+        f = cf.Field(properties=properties)
+        f.insert_dim(dim0)
+        f.insert_dim(dim1)
+        f.insert_data(data)
+
         print_f = str(f)
 
         self.assertTrue(
-            print_f == 
-'''eastward_wind field summary
----------------------------
+            print_f == '''Field: eastward_wind
+--------------------
 Data           : eastward_wind(latitude(10), longitude(9)) m s-1
-Axes           : longitude(9) = [0, ..., 8] degrees_east
-               : latitude(10) = [0, ..., 9] degrees_north
+Axes           : latitude(10) = [0, ..., 9] degrees_north
+               : longitude(9) = [0, ..., 8] degrees_east
 ''')
 
         aux = cf.AuxiliaryCoordinate(data=cf.Data(['alpha','beta','gamma','delta','epsilon',
@@ -51,17 +56,17 @@ Axes           : longitude(9) = [0, ..., 8] degrees_east
 
         aux.long_name = 'extra'
         f.insert_aux(aux, axes=['dim0'])
-        f.cell_methods = cf.CellMethods('latitude: point')
+        f.insert_cell_methods('latitude: point')
         f.long_name = 'wind' 
         print_f = str(f)
 
         self.assertTrue(
-            print_f == '''eastward_wind field summary
----------------------------
+            print_f == '''Field: eastward_wind
+--------------------
 Data           : eastward_wind(latitude(10), longitude(9)) m s-1
 Cell methods   : latitude: point
-Axes           : longitude(9) = [0, ..., 8] degrees_east
-               : latitude(10) = [0, ..., 9] degrees_north
+Axes           : latitude(10) = [0, ..., 9] degrees_north
+               : longitude(9) = [0, ..., 8] degrees_east
 Aux coords     : long_name:extra(latitude(10)) = [alpha, ..., kappa]
 ''')
 
@@ -70,11 +75,11 @@ Aux coords     : long_name:extra(latitude(10)) = [alpha, ..., kappa]
         print_f = str(f)
 
         self.assertTrue(
-            print_f == '''eastward_wind field summary
----------------------------
+            print_f == '''Field: eastward_wind
+--------------------
 Data           : eastward_wind(latitude(10), longitude(9)) m s-1
-Axes           : longitude(9) = [0, ..., 8] degrees_east
-               : latitude(10) = [0, ..., 9] degrees_north
+Axes           : latitude(10) = [0, ..., 9] degrees_north
+               : longitude(9) = [0, ..., 8] degrees_east
 ''')
     #--- End: def
 
@@ -84,15 +89,16 @@ Axes           : longitude(9) = [0, ..., 8] degrees_east
         #---------------------------------------------------------------------
         # Create a grid_latitude dimension coordinate
         Y = cf.DimensionCoordinate(properties={'standard_name': 'grid_latitude'},
-                                      data=cf.Data(numpy.arange(10.), 'degrees'))
+                                   data=cf.Data(numpy.arange(10.), 'degrees'))
         
         # Create a grid_longitude dimension coordinate
         X = cf.DimensionCoordinate(data=cf.Data(numpy.arange(9.), 'degrees'))
         X.standard_name = 'grid_longitude'
         
         # Create a time dimension coordinate (with bounds)
-        bounds = cf.CoordinateBounds(
-            data=cf.Data([0.5, 1.5], cf.Units('days since 2000-1-1', calendar='noleap')))
+        bounds = cf.Bounds(
+            data=cf.Data([0.5, 1.5],
+                         cf.Units('days since 2000-1-1', calendar='noleap')))
         T = cf.DimensionCoordinate(properties=dict(standard_name='time'),
                                    data=cf.Data(1, cf.Units('days since 2000-1-1',
                                                             calendar='noleap')),
@@ -110,37 +116,41 @@ Axes           : longitude(9) = [0, ..., 8] degrees_east
         
         # Create a rotated_latitude_longitude grid mapping coordinate reference
         grid_mapping = cf.CoordinateReference('rotated_latitude_longitude',
-                                              grid_north_pole_latitude=38.0,
-                                              grid_north_pole_longitude=190.0)
+                                              parameters={
+                                                  'grid_north_pole_latitude': 38.0,
+                                                  'grid_north_pole_longitude': 190.0})
         
-        # --------------------------------------------------------------------
-        # 2. Create the field's domain from the previously created items
-        # --------------------------------------------------------------------
-        domain = cf.Domain(dim=[T, Y, X],
-                           aux=[lat, lon],
-                           ref=grid_mapping)
-
         #---------------------------------------------------------------------
         # 3. Create the field
         #---------------------------------------------------------------------
         # Create CF properties
         properties = {'standard_name': 'eastward_wind',
-                      'long_name'    : 'East Wind',
-                      'cell_methods' : cf.CellMethods('latitude: point')}
-        
+                      'long_name'    : 'East Wind'}
+
         # Create the field's data array
         data = cf.Data(numpy.arange(90.).reshape(9, 10), 'm s-1')
         
         # Finally, create the field
-        f = cf.Field(properties=properties,
-                     domain=domain,
-                     data=data)
-        
+        f = cf.Field(properties=properties)
+
+        f.insert_cell_methods('latitude: point')
+
+        f.insert_dim(T)
+        f.insert_dim(X)
+        f.insert_dim(Y)
+
+        f.insert_aux(lat)
+        f.insert_aux(lon)
+
+        f.insert_ref(grid_mapping)
+
+        f.insert_data(data)
+
         print_f = str(f)
 
         self.assertTrue(
-            print_f == '''eastward_wind field summary
----------------------------
+            print_f == '''Field: eastward_wind
+--------------------
 Data           : eastward_wind(grid_longitude(9), grid_latitude(10)) m s-1
 Cell methods   : latitude: point
 Axes           : time(1) = [2000-01-02T00:00:00Z] noleap
@@ -148,7 +158,7 @@ Axes           : time(1) = [2000-01-02T00:00:00Z] noleap
                : grid_latitude(10) = [0.0, ..., 9.0] degrees
 Aux coords     : latitude(grid_latitude(10), grid_longitude(9)) = [[0, ..., 89]] degrees_north
                : longitude(grid_longitude(9), grid_latitude(10)) = [[1, ..., 90]] degrees_east
-Coord refs     : <CF CoordinateReference: rotated_latitude_longitude>
+Coord refs     : rotated_latitude_longitude
 ''')
     #--- End: def
 
@@ -156,7 +166,6 @@ Coord refs     : <CF CoordinateReference: rotated_latitude_longitude>
         import cf
         import numpy
         
-     
         #---------------------------------------------------------------------
         # 1. CREATE the field's domain items
         #---------------------------------------------------------------------
@@ -167,9 +176,9 @@ Coord refs     : <CF CoordinateReference: rotated_latitude_longitude>
         # Create a grid_longitude dimension coordinate
         X = cf.DimensionCoordinate(data=cf.Data(numpy.arange(10.), 'degrees'))
         X.standard_name = 'grid_longitude'
-        
+
         # Create a time dimension coordinate (with bounds)
-        bounds = cf.CoordinateBounds(
+        bounds = cf.Bounds(
             data=cf.Data([0.5, 1.5], cf.Units('days since 2000-1-1', calendar='noleap')))
         T = cf.DimensionCoordinate(properties=dict(standard_name='time'),
                                    data=cf.Data(1, cf.Units('days since 2000-1-1',
@@ -188,48 +197,49 @@ Coord refs     : <CF CoordinateReference: rotated_latitude_longitude>
         
         # Create a rotated_latitude_longitude grid mapping coordinate reference
         grid_mapping = cf.CoordinateReference('rotated_latitude_longitude',
-                                              grid_north_pole_latitude=38.0,
-                                              grid_north_pole_longitude=190.0)
-        
-        # --------------------------------------------------------------------
-        # 2. Create the field's domain from the previously created items
-        # --------------------------------------------------------------------
-        domain = cf.Domain(dim=[T, Y, X],
-                           aux={'aux0': lat, 'aux1': lon},
-                           ref=grid_mapping,
-     		      assign_axes={'aux0': ['grid_latitude', 'grid_longitude'],
-                               	   'aux1': ['grid_longitude', 'grid_latitude']})
+                                              parameters={
+                                                  'grid_north_pole_latitude': 38.0,
+                                                  'grid_north_pole_longitude': 190.0})
      
         #---------------------------------------------------------------------
         # 3. Create the field
         #---------------------------------------------------------------------
         # Create CF properties
         properties = {'standard_name': 'eastward_wind',
-                      'long_name'    : 'East Wind',
-                      'cell_methods' : cf.CellMethods('latitude: point')}
+                      'long_name'    : 'Eastward Wind'}
         
         # Create the field's data array
         data = cf.Data(numpy.arange(100.).reshape(10, 10), 'm s-1')
         
         # Finally, create the field
-        f = cf.Field(properties=properties,
-                     domain=domain,
-                     data=data,
-                     axes=['grid_latitude', 'grid_longitude'])
-         
+        f = cf.Field(properties=properties)
+
+        f.insert_cell_methods('latitude: point')
+
+        f.insert_dim(T)
+        f.insert_dim(X)
+        f.insert_dim(Y)
+
+        f.insert_aux(lat, axes=['Y', 'X'])
+        f.insert_aux(lon, axes=['X', 'Y'])
+
+        f.insert_ref(grid_mapping)
+
+        f.insert_data(data, axes=['Y', 'X'])
+
         print_f = str(f)
 
         self.assertTrue(
-           print_f == '''eastward_wind field summary
----------------------------
+            print_f == '''Field: eastward_wind
+--------------------
 Data           : eastward_wind(grid_latitude(10), grid_longitude(10)) m s-1
 Cell methods   : latitude: point
 Axes           : time(1) = [2000-01-02T00:00:00Z] noleap
-               : grid_longitude(10) = [0.0, ..., 9.0] degrees
                : grid_latitude(10) = [0.0, ..., 9.0] degrees
+               : grid_longitude(10) = [0.0, ..., 9.0] degrees
 Aux coords     : latitude(grid_latitude(10), grid_longitude(10)) = [[0, ..., 99]] degrees_north
                : longitude(grid_longitude(10), grid_latitude(10)) = [[1, ..., 100]] degrees_east
-Coord refs     : <CF CoordinateReference: rotated_latitude_longitude>
+Coord refs     : rotated_latitude_longitude
 ''')
     #--- End: def
 
@@ -238,8 +248,6 @@ Coord refs     : <CF CoordinateReference: rotated_latitude_longitude>
 if __name__ == '__main__':
     print 'Run date:', datetime.datetime.now()
     cf.environment()
-#    print 'cf-python version:'     , cf.__version__
-#    print 'cf-python path:'        , os.path.abspath(cf.__file__)
     print ''
     unittest.main(verbosity=2)
 
